package com.djhk.uav.uav.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.djhk.uav.uav.model.UavBattery;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 运力Mapper接口
 *
 * @author jiachengshuai
 * @date 2023-02-21
 */
@Mapper
public interface UavBatteryMapper extends BaseMapper<UavBattery>
{
    /**
     * 查询运力
     *
     * @param id 运力主键
     * @return 运力
     */
    public UavBattery selectUavBatteryById(Long id);

    /**
     * 查询运力列表
     *
     * @param uavBattery 运力
     * @return 运力集合
     */
    public List<UavBattery> selectUavBatteryList(UavBattery uavBattery);

    /**
     * 新增运力
     *
     * @param uavBattery 运力
     * @return 结果
     */
    public int insertUavBattery(UavBattery uavBattery);

    /**
     * 修改运力
     *
     * @param uavBattery 运力
     * @return 结果
     */
    public int updateUavBattery(UavBattery uavBattery);

    /**
     * 删除运力
     *
     * @param id 运力主键
     * @return 结果
     */
    public int deleteUavBatteryById(Long id);

    /**
     * 批量删除运力
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteUavBatteryByIds(Long[] ids);
}
